Home  |  Linux  | Mysql  | PHP  | XML
From:jhorwitz@cvs.perl.org Date:Sun Sep 21 10:23:28 2008
Subject:[svn:mod_parrot] r445 - mod_parrot/branches/hll-modules/src
Author: jhorwitz
Date: Sun Sep 21 09:23:27 2008
New Revision: 445

Modified:
   mod_parrot/branches/hll-modules/src/modparrot_config.c

Log:
merge modules_array in modparrot_srv_config


Modified: mod_parrot/branches/hll-modules/src/modparrot_config.c
==============================================================================
--- mod_parrot/branches/hll-modules/src/modparrot_config.c	(original)
+++ mod_parrot/branches/hll-modules/src/modparrot_config.c	Sun Sep 21 09:23:27 2008
@@ -107,9 +107,10 @@
         merged->option_flags &= ~(newcfg->disable_option_flags);
     }
 
     /* modules hash is only set in main server, so just copy */
     /* XXX need to enforce this
     newcfg->modules = apr_hash_copy(p, basecfg->modules);
+    newcfg->module_array = apr_array_copy(p, basecfg->module_array);
 
     /* merges specific to the Parent option */
     if (newcfg->option_flags & MP_OPT_PARENT) {
@@ -107,9 +107,10 @@
     }
 
-    /* modules hash is only set in main server, so just copy */
+    /* modules hash and array are only set in main server, so just copy */
     /* XXX need to enforce this
     newcfg->modules = apr_hash_copy(p, basecfg->modules);
Navigate in group perl.cvs.mod_parrot at sever nntp.perl.org
Previous Next




  
© No Copyright
You are free to use Anything
Site Maintained by PHP Developer
Powered By PHP Consultants